==> jc-1.4.0.tar.gz: java/awt/Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler.h <==
// public class java.awt.Component$AccessibleAWTComponent$AccessibleAWTComponentHandler

// class file dependencies
// @dep_class 4f680896d5dabdb9 java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_
#define _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_Component__24AccessibleAWTComponent$object;
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object;

typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype;

// Constructors
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$_init$e04fee3361fa61e5(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_Component__24AccessibleAWTComponent$object *);

// Virtual methods
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *);
};

// Vtable
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
};

// Vtype
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs {
	struct _jc_java_awt_Component__24AccessibleAWTComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs {
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
};

// Object instance structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object {
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype	*vtype;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$class_object;

#endif	/* _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_ */

==> jc-1.4.5.tar.gz: java/awt/Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler.h <==
// public class java.awt.Component$AccessibleAWTComponent$AccessibleAWTComponentHandler

// class file dependencies
// @dep_class d6a3744c6a77f166 java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_
#define _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_

// Forward structure declarations
struct _jc_java_awt_Component__24AccessibleAWTComponent$object;
struct _jc_java_awt_event_ComponentEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs;
typedef struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object;

typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable;
typedef const struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype;

// Constructors
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$_init$e04fee3361fa61e5(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_Component__24AccessibleAWTComponent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentHidden$c45a3d9480cd8f67(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentMoved$81a358183048de7c(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentResized$ac5fcd90b88c07ec(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method$componentShown$f9db658060a8b292(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentHidden$c45a3d9480cd8f67;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentMoved$81a358183048de7c;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentResized$ac5fcd90b88c07ec;
extern _jc_method _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$method_info$componentShown$f9db658060a8b292;

// Virtual methods structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods {
	void	(*componentHidden$c45a3d9480cd8f67)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentMoved$81a358183048de7c)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentResized$ac5fcd90b88c07ec)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
	void	(*componentShown$f9db658060a8b292)(_jc_env *, struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object *, struct _jc_java_awt_event_ComponentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vmethods	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
};

// Vtype
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype {
	_jc_type			type;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs {
	struct _jc_java_awt_Component__24AccessibleAWTComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs {
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_refs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$sub_nonrefs	java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler;
};

// Object instance structure
struct _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$object {
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype	*vtype;
	_jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$vtype _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler$class_object;

#endif	/* _JC_java_awt_Component__24AccessibleAWTComponent__24AccessibleAWTComponentHandler_H_ */
